#' GetAdjustmentSpec
#'
#' Returns adjustment specification list object.
#'
#' @param fileName Name of adjustment specification file. Required.
#' @param section Name of section of the adjustment specification to return. If not specified, then
#'   the whole specification is returned, otherwise only the specified section. Optional.
#'   Default = NULL.
#'
#' @return List object.
#'
#' @examples
#' \dontrun{
#' GetAdjustmentSpec(fileName)
#' GetAdjustmentSpec(fileName, section = "Name")
#' GetAdjustmentSpec(fileName, section = "Parameters")
#' }
#'
#' @export
GetAdjustmentSpec <- function(fileName, section = NULL)
{
  stopifnot(!missing(fileName))

  # Get entire specifiction
  adjustmentSpec <- eval(expr = parse(file = fileName))

  # Return only a specific section of the specification
  if (!is.null(section)) {
    if (section %in% names(adjustmentSpec)) {
      adjustmentSpec <- adjustmentSpec[[section]]
    }
  }

  return(adjustmentSpec)
}
